@@ -7,6 +7,6 @@ from cert_schema.jsonld_helpers import BLOCKCERTS_V3_ALPHA_CANONICAL_CONTEXT, BL
     BLOCKCERTS_V3_ALPHA_SCHEMA, VERIFIABLE_CREDENTIAL_V1_CONTEXT, BLOCKCERTS_V2_ALPHA_CONTEXT, \
     BLOCKCERTS_V2_ALPHA_SCHEMA, BLOCKCERTS_V2_CONTEXT, BLOCKCERTS_V2_SCHEMA, BLOCKCERTS_V2_CANONICAL_CONTEXT, \
     BLOCKCERTS_VOCAB, JSONLD_OPTIONS, OPEN_BADGES_V2_CANONICAL_CONTEXT, OPEN_BADGES_V2_CONTEXT, SECURITY_CONTEXT_URL, \
-    BLOCKCERTS_V2_1_CONTEXT, BLOCKCERTS_V2_1_SCHEMA, BLOCKCERTS_V2_1_CANONICAL_CONTEXT
+    BLOCKCERTS_V2_1_CONTEXT, BLOCKCERTS_V2_1_SCHEMA, BLOCKCERTS_V2_1_CANONICAL_CONTEXT, BLOXBERG_V1_CONTEXT, BLOXBERG_V1_SCHEMA, BLOXBERG_V1_CANONICAL_CONTEXT
 
 from cert_schema.errors import *
